=======
Credits
=======

List of people who helped with development of this library. Feel free to add your name to the list, if you've made a
contribution.

Development Lead
----------------

* Ondřej Kulatý <kulaty.o@gmail.com>

Contributors
------------

* Luboš Mátl
* Petr Olah
